<template>
<!--履行/放弃权利申请书-->
  <el-main>
    <el-form ref="form" :model="form" :disabled="form.registerState == '1'">
      <el-form-item label="执法局名称" :label-width="formLabelWidth">
        <el-input v-model="form.agencyName" autocomplete="off"></el-input>
      </el-form-item>
      <el-form-item label="文号" :label-width="formLabelWidth">
        <el-input v-model="form.unitName" autocomplete="off"></el-input>
      </el-form-item>
      <el-row>
<!--        <el-col :span="12">-->
<!--          <el-form-item label="申请人签名" :label-width="formLabelWidth">-->
<!--            <el-input-->
<!--              v-model="form.applicant"-->
<!--              autocomplete="off"-->
<!--            ></el-input>-->
<!--          </el-form-item>-->
<!--        </el-col>-->
        <el-col :span="12">
          <el-form-item label="申请日期" :label-width="formLabelWidth">
            <el-date-picker
              v-model="form.applicationTime"
              type="date"
              :value-format="`yyyy-MM-dd`"
              placeholder="选择日期"
              style="width: 100%"
            >
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <WordView ref="wordInfo" :isShowYulan="showView" @cancel="cancelWord"></WordView>
    </el-form>
    <div style="text-align: center;">
      <el-button v-show="form.registerState != '1'" plain @click="dataFormSubmit('0')">保存</el-button>
      <el-button v-show="form.registerState != '1'" type="warning" plain @click="dataFormSubmit('1')">定稿</el-button>
      <el-button type="primary" plain @click="viewVord(form)">预览</el-button>
      <el-button type="success" plain @click="downloadWord(form)">下载</el-button>
    </div>
  </el-main>
</template>

<script>
import WordView from "@/views/News/word-view";
import {getObj, saveObj} from "@/api/News/applicationForRights";
import moment from "moment";

export default {
  name: "applicationForRights",
  props: ['isShowYulan','id','isFinish','processId','title'],
  components: {
    WordView
  },
  data() {
    return {
      showView: false,
      form: {
        agencyName: "",
        unitName: "",
        applicant: "",
        applicationTime: "",
      },
      formLabelWidth: "140px",
    };
  },
  created() {
    this.init()
  },
  methods: {
    init() {
      getObj(this.id).then((res) => {
        if (res.data.code == 0) {
          // 转换null为""
          let v = res.data.data;
          for (let attr in v) {
            if (v[attr] == null) {
              v[attr] = "";
            }
          }
          let str = JSON.stringify(v);
          let data = JSON.parse(str);
          this.form = data;
        }
      });
    },
    dataFormSubmit(type) {
      console.log(type)
      this.$refs['form'].validate((valid) => {
        if (valid) {
          let obj = this;
          if ("1" == type) {
            this.$confirm('保存为定稿将不能修改，是否继续？', '提示', {
              confirmButtonText: '是',
              cancelButtonText: '否',
              type: 'warning'
            }).then(function () {
              obj.form.registerState = type;
              obj.form.registerId = obj.id;
              obj.form.processId = obj.processId;
              saveObj(obj.form).then((res) => {
                // this.submitLoading = false;
                obj.$message.success('操作成功');
                obj.cancel();
              })
            })
          } else {
            obj.form.registerState = type;
            obj.form.registerId = obj.id;
            obj.form.processId = obj.processId;
            saveObj(obj.form).then((res) => {
              // this.submitLoading = false;
              obj.$message.success("操作成功");
              obj.cancel();
            })
          }
        }
      })
    },
    cancel() {
      this.$emit('cancel', false);
    },
    cancelWord() {
      this.showView = false;
    },
    viewVord(data) {
      if(data.registerState == null || data.registerState == ""){
        //预览前先进行保存
        data.registerState = '0';
        data.registerId = this.id;
        data.processId = this.processId;
        saveObj(data).then((res) => {
        })
      }
      //↓↓↓↓↓↓以下部分根据具体业务修改↓↓↓↓↓↓
      //格式转换
      let wordData = this.transforData(data);
      //↑↑↑↑↑↑以上部分根据具体业务修改↑↑↑↑↑↑
      this.showView = true;
      this.$nextTick(() => {
        this.$refs.wordInfo.init(wordData, "/wordes/applicationForRights.docx");
      })
    },
    downloadWord(data) {
      if(data.registerState == null || data.registerState == ""){
        //预览前先进行保存
        data.registerState = '0';
        data.registerId = this.id;
        data.processId = this.processId;
        saveObj(data).then((res) => {
        })
      }
      let wordData = this.transforData(data);
      WordView.methods.exportDoc(wordData, "/wordes/applicationForRights.docx", this.title+'.docx');
    },
    transforData(obj) {
      let s = JSON.stringify(obj);
      let data = JSON.parse(s);
      if (data.applicationTime != '' && data.applicationTime != null) {
        data.applicationTime = moment(data.applicationTime).format('YYYY年MM月DD日');
      }else {
        data.applicationTime = '  年  月  日'
      }

      return data;
    }
  }
}
</script>

<style scoped>

</style>
